@@ -1,9 +1,9 @@
-## ----tram-setup, echo = FALSE, results = "hide", message = FALSE---------
+## ----tram-setup, echo = FALSE, results = "hide", message = FALSE, warning = FALSE----
 set.seed(290875)
 
-sapply(c("tram", "survival", "MASS", "lattice", "mlbench", 
-         "multcomp", "ordinal", "colorspace", "quantreg", "trtf", "ATR"), library, char = TRUE)
-
+pkgs <- sapply(c("tram", "survival", "MASS", "lattice", "mlbench", 
+         "multcomp", "ordinal", "colorspace", "quantreg", "trtf", "ATR"), 
+         require, char = TRUE)
 
 trellis.par.set(list(plot.symbol = list(col=1,pch=20, cex=0.7),
                      box.rectangle = list(col=1),
@@ -33,6 +33,14 @@ fill <- diverge_hcl(2, h = c(246, 40), c = 96, l = c(65, 90), alpha = .3)
 year <- substr(packageDescription("tram")$Date, 1, 4)
 version <- packageDescription("tram")$Version
 
+## ----fail, results = "asis", echo = FALSE--------------------------------
+if (any(!pkgs)) {
+    cat(paste("Package(s)", paste(names(pkgs)[!pkgs], collapse = ", "), 
+        "not available, stop processing.",
+        "\\end{document}\n"))
+    knitr::knit_exit()
+}
+
 ## ----tram-tram, echo = TRUE, eval = FALSE--------------------------------
 #  tram(y | s ~ x, ...)
 
